@@ -69,8 +69,9 @@ use Sys::Virt::Interface;
 use Sys::Virt::Secret;
 use Sys::Virt::NWFilter;
 use Sys::Virt::DomainSnapshot;
+use Sys::Virt::Stream;
 
-our $VERSION = '0.2.6';
+our $VERSION = '0.2.7';
 require XSLoader;
 XSLoader::load('Sys::Virt', $VERSION);
 
@@ -191,6 +192,20 @@ sub new {
 }
 
 
+=item my $st = $vmm->new_stream($flags)
+
+Create a new stream, with the given flags
+
+=cut
+
+sub new_stream {
+    my $self = shift;
+    my $flags = shift || 0;
+
+    return Sys::Virt::Stream->_new(connection => $self, flags => $flags);
+}
+
+
 =item my $dom = $vmm->create_domain($xml, $flags);
 
 Create a new domain based on the XML description passed into the C<$xml>
@@ -1012,6 +1027,11 @@ Return the URI associated with the open connection. This may be different
 from the URI used when initially connecting to libvirt, when 'auto-probing'
 or drivers occurrs.
 
+=item my $xml = $vmm->get_sysinfo()
+
+Return an XML documenting representing the host system information,
+typically obtained from SMBIOS tables.
+
 =item my $type = $vmm->get_type()
 
 Return the type of virtualization backend accessed by this VMM object. Currently
